pub enum AppStatus {
Draft,
Published,
Archived,
Deleted,
}Expand description
App lifecycle status.
draft: App is configured but not accepting requestspublished: App is live, accepting incoming requestsarchived: App is hidden from listings and cannot be modified or assigneddeleted: App is a tombstone kept only for historical references
Variants