InputAtom

Struct InputAtom 

pub struct InputAtom<M>{ /* private fields */ }
Atom that retrieves user input for a turn

This atom:

  1. Retrieves the user message from the message retriever using input_message_id
  2. Returns the message for downstream processing

The message is expected to already be stored by the API layer (which emits input.message). This atom just retrieves it and prepares for the turn.

Implementations

Source

impl<M> InputAtom<M>

pub fn new(message_retriever: M) -> Self

Create a new InputAtom