pub struct BotAuthPublicKey {
pub key_id: String,
pub jwk: Value,
}Expand description
Ed25519 public key JWK derived from a signing key seed.
Used to register the public key in the HTTP message signatures directory so target servers can verify request signatures.
Fields
key_id: StringJWK Thumbprint (RFC 7638) — matches BotAuthConfig::keyid()
jwk: ValueFull JWK object: {"kty":"OKP","crv":"Ed25519","x":"<base64url>"}