pub struct EmbedRequest {
pub texts: Vec<String>,
pub model: String,
}Expand description
Request to embed a batch of text strings into dense vectors.
Fields
texts: Vec<String>Texts to embed. All texts in a batch share the same model.
model: StringProvider-side model id (e.g. text-embedding-3-small).