pub struct OpenRouterMaxPrice {
pub prompt: Option<f64>,
pub completion: Option<f64>,
pub request: Option<f64>,
pub image: Option<f64>,
}Expand description
Maximum accepted OpenRouter provider pricing, expressed in dollars per million prompt/completion tokens or per request/image where supported.
Fields
prompt: Option<f64>completion: Option<f64>request: Option<f64>image: Option<f64>Trait Implementations
Sourceimpl Clone for OpenRouterMaxPrice
impl Clone for OpenRouterMaxPrice
Sourcefn clone(&self) -> OpenRouterMaxPrice
fn clone(&self) -> OpenRouterMaxPrice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpenRouterMaxPrice
impl Debug for OpenRouterMaxPrice
Sourceimpl Default for OpenRouterMaxPrice
impl Default for OpenRouterMaxPrice
Sourcefn default() -> OpenRouterMaxPrice
fn default() -> OpenRouterMaxPrice
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OpenRouterMaxPrice
impl<'de> Deserialize<'de> for OpenRouterMaxPrice
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for OpenRouterMaxPrice
impl PartialEq for OpenRouterMaxPrice
Sourcefn eq(&self, other: &OpenRouterMaxPrice) -> bool
fn eq(&self, other: &OpenRouterMaxPrice) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OpenRouterMaxPrice
impl Serialize for OpenRouterMaxPrice
impl StructuralPartialEq for OpenRouterMaxPrice