pub enum ProviderOpaqueContext {
OpenResponsesCompact {
output: Vec<CompactOutputItem>,
},
}Expand description
Ordered provider-owned context returned by a native compaction operation.
The runtime carries this value without interpreting or exposing its opaque payload. The matching provider driver is responsible for putting the items back on the wire exactly as returned.
Variants
OpenResponsesCompact
Standalone output returned by OpenAI /responses/compact.
Fields

output: Vec<CompactOutputItem>Trait Implementations
Sourceimpl Clone for ProviderOpaqueContext
impl Clone for ProviderOpaqueContext
Sourcefn clone(&self) -> ProviderOpaqueContext
fn clone(&self) -> ProviderOpaqueContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderOpaqueContext
impl Debug for ProviderOpaqueContext
Sourceimpl<'de> Deserialize<'de> for ProviderOpaqueContext
impl<'de> Deserialize<'de> for ProviderOpaqueContext
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ProviderOpaqueContext, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ProviderOpaqueContext, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderOpaqueContext
Sourceimpl PartialEq for ProviderOpaqueContext
impl PartialEq for ProviderOpaqueContext
Sourceimpl Serialize for ProviderOpaqueContext
impl Serialize for ProviderOpaqueContext
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ProviderOpaqueContext