Module eval

Module eval 

Structs

ArtifactSpec
Named session file to collect after an eval case completes.
Eval
An eval: a named collection of test cases for an agent.
EvalCase
A single test case within an eval.
EvalCaseResult
Result of a single case within a run.
EvalInputMessage
A message to send to the agent during an eval case.
EvalRun
An eval run: one execution of all/some cases.
EvalRunDataset
An async dataset-export handle: the durable result of enqueuing a dataset export from a completed eval run. The body (NDJSON) is only populated on the GET .../dataset/{dataset_id} detail view once status is completed.
EvalRunSummaryView
Compact run summary for listing evals.
RunSummary
Aggregate metrics for a completed eval run.
Score
Result from a single scorer evaluation.

Enums

CaseResultStatus
Status of an individual eval case result.
EvalDatasetStatus
Status of an async dataset export.
EvalRunSource
Where an eval run came from.
EvalRunStatus
Status of an eval run.
EvalStatus
Eval lifecycle status (standard building-block lifecycle).
EvalTarget
Defines how to instantiate a session for an eval case.
Scorer
A scoring rule applied to eval case output.