pub struct LlmGenerationData {
pub messages: Vec<Message>,
pub tools: Vec<ToolDefinitionSummary>,
pub output: LlmGenerationOutput,
pub metadata: LlmGenerationMetadata,
}Expand description
Data for llm.generation event
Emitted after each LLM API call to provide full visibility into the messages sent to the model and the response received.
Fields
messages: Vec<Message>Messages sent to the LLM (including system prompt)
tools: Vec<ToolDefinitionSummary>Tools available to the LLM for this generation
output: LlmGenerationOutputOutput from the LLM
metadata: LlmGenerationMetadataMetadata about the generation
Implementations
Sourceimpl LlmGenerationData
impl LlmGenerationData
Sourcepub fn success(
messages: Vec<Message>,
tools: Vec<ToolDefinitionSummary>,
text: Option<String>,
tool_calls: Vec<ToolCall>,
model: String,
provider: Option<String>,
usage: Option<TokenUsage>,
duration_ms: Option<u64>,
time_to_first_token_ms: Option<u64>,
) -> Self
pub fn success( messages: Vec<Message>, tools: Vec<ToolDefinitionSummary>, text: Option<String>, tool_calls: Vec<ToolCall>, model: String, provider: Option<String>, usage: Option<TokenUsage>, duration_ms: Option<u64>, time_to_first_token_ms: Option<u64>, ) -> Self
Create a successful generation event
Sourcepub fn success_with_metadata(
messages: Vec<Message>,
tools: Vec<ToolDefinitionSummary>,
text: Option<String>,
tool_calls: Vec<ToolCall>,
model: String,
provider: Option<String>,
usage: Option<TokenUsage>,
duration_ms: Option<u64>,
time_to_first_token_ms: Option<u64>,
finish_reasons: Option<Vec<String>>,
response_id: Option<String>,
) -> Self
pub fn success_with_metadata( messages: Vec<Message>, tools: Vec<ToolDefinitionSummary>, text: Option<String>, tool_calls: Vec<ToolCall>, model: String, provider: Option<String>, usage: Option<TokenUsage>, duration_ms: Option<u64>, time_to_first_token_ms: Option<u64>, finish_reasons: Option<Vec<String>>, response_id: Option<String>, ) -> Self
Create a successful generation event with full metadata
Sourcepub fn success_with_retry(
messages: Vec<Message>,
tools: Vec<ToolDefinitionSummary>,
text: Option<String>,
tool_calls: Vec<ToolCall>,
model: String,
provider: Option<String>,
usage: Option<TokenUsage>,
duration_ms: Option<u64>,
time_to_first_token_ms: Option<u64>,
finish_reasons: Option<Vec<String>>,
response_id: Option<String>,
retry: Option<LlmRetryInfo>,
) -> Self
pub fn success_with_retry( messages: Vec<Message>, tools: Vec<ToolDefinitionSummary>, text: Option<String>, tool_calls: Vec<ToolCall>, model: String, provider: Option<String>, usage: Option<TokenUsage>, duration_ms: Option<u64>, time_to_first_token_ms: Option<u64>, finish_reasons: Option<Vec<String>>, response_id: Option<String>, retry: Option<LlmRetryInfo>, ) -> Self
Create a successful generation event with retry information
Sourcepub fn failure(
messages: Vec<Message>,
tools: Vec<ToolDefinitionSummary>,
model: String,
provider: Option<String>,
error: String,
duration_ms: Option<u64>,
time_to_first_token_ms: Option<u64>,
) -> Self
pub fn failure( messages: Vec<Message>, tools: Vec<ToolDefinitionSummary>, model: String, provider: Option<String>, error: String, duration_ms: Option<u64>, time_to_first_token_ms: Option<u64>, ) -> Self
Create a failed generation event
Sourcepub fn with_compaction(self, compaction: LlmCompactionInfo) -> Self
pub fn with_compaction(self, compaction: LlmCompactionInfo) -> Self
Set compaction info on this generation event
Call this when context was compacted before a successful retry.
Sourcepub fn with_retry(self, retry: LlmRetryInfo) -> Self
pub fn with_retry(self, retry: LlmRetryInfo) -> Self
Set retry info on this generation event
Sourcepub fn with_request_options(self, request_options: LlmRequestOptions) -> Self
pub fn with_request_options(self, request_options: LlmRequestOptions) -> Self
Set request-side options on this generation event.