Module execution_context

Module execution_context 

Transport-neutral context shared by execution phases and emitted events.

Structs

ExecutionContext
Correlation and resource identity for one execution phase within a turn.