pub enum HarnessStatus {
Active,
Archived,
Deleted,
}Expand description
Harness lifecycle status.
active: Harness is available for usearchived: Harness is hidden from listings and cannot be modified or assigneddeleted: Harness is a tombstone kept only for historical references
Variants
Active
Harness is available for use.
Archived
Harness is hidden from listings and cannot be modified or assigned.
Deleted
Harness is deleted and should only survive as a tombstone for references.