pub enum McpServerStatus {
Active,
Disabled,
Archived,
Deleted,
}Expand description
MCP Server lifecycle status.
active: Server is available for usedisabled: Server is disabled and not usedarchived: Server is hidden from listings and cannot be modified or assigneddeleted: Server is a tombstone kept only for historical references
Variants
Active
Server is available for use.
Disabled
Server is disabled and not used.
Archived
Server is hidden from listings and cannot be modified or assigned.
Deleted
Server is deleted and should only survive as a tombstone for references.