ModelProfile

Struct ModelProfile 

pub struct ModelProfile {
Show 20 fields pub name: String, pub family: String, pub description: Option<String>, pub release_date: Option<String>, pub last_updated: Option<String>, pub attachment: bool, pub reasoning: bool, pub temperature: bool, pub knowledge: Option<String>, pub tool_call: bool, pub structured_output: bool, pub open_weights: bool, pub cost: Option<ModelCost>, pub limits: Option<ModelLimits>, pub modalities: Option<ModelModalities>, pub reasoning_effort: Option<ReasoningEffortConfig>, pub speed: Option<SpeedConfig>, pub tool_search: bool, pub supported_parameters: Vec<String>, pub supports_phases: bool,
}
LLM Model Profile describing model capabilities Based on models.dev structure (https://models.dev/api.json)

NOTE: Currently only includes profiles for:

  • OpenAI: gpt-4o, gpt-4o-mini, o1, o1-mini, o1-pro, o3-mini
  • Anthropic: claude-3-5-sonnet, claude-3-5-haiku, claude-3-opus, claude-3-sonnet, claude-3-haiku, claude-sonnet-4, claude-opus-4

Additional model profiles can be added as needed.

Fields

name: String

Display name of the model

family: String

Model family (e.g., “gpt-4o”, “claude-3-5-sonnet”)

description: Option<String>

Short human-readable description of the model’s strengths and intended use

release_date: Option<String>

Release date (YYYY-MM-DD format)

last_updated: Option<String>

Last updated date (YYYY-MM-DD format)

attachment: bool

Whether the model supports file/image attachments

reasoning: bool

Whether the model has reasoning/chain-of-thought capabilities

temperature: bool

Whether temperature control is supported

knowledge: Option<String>

Knowledge cutoff date (YYYY-MM-DD format)

tool_call: bool

Whether the model supports tool/function calling

structured_output: bool

Whether the model supports structured output (JSON mode)

open_weights: bool

Whether the model has open weights

cost: Option<ModelCost>

Cost per million tokens

limits: Option<ModelLimits>

Token limits

modalities: Option<ModelModalities>

Supported modalities

reasoning_effort: Option<ReasoningEffortConfig>

Reasoning effort configuration (for reasoning models)

speed: Option<SpeedConfig>

Speed (service tier) configuration, for models served with selectable latency/price tiers (OpenAI service_tier).

tool_search: bool

Whether the model supports tool_search (deferred tool loading). When true, the driver can use namespaces and defer_loading to reduce token usage for large tool sets. Currently supported by GPT-5.4 and newer.

supported_parameters: Vec<String>

Provider-advertised request parameters supported by this model.

supports_phases: bool

Whether the model supports native execution phases (“commentary” / “final_answer”). When true, the driver sends the phase field on assistant messages in the wire format. Currently supported by GPT-5.4 and newer via OpenAI Responses API.