pub enum CompactOutputItem {
Message {
role: String,
content: CompactContent,
},
Compaction {
encrypted_content: String,
},
}Expand description
Output item from compact response
Variants
Implementations
Sourceimpl CompactOutputItem
impl CompactOutputItem
Sourcepub fn to_llm_message(&self) -> Option<LlmMessage>
pub fn to_llm_message(&self) -> Option<LlmMessage>
Convert a CompactOutputItem to LlmMessage
Compaction items are converted to a special system message containing the encrypted context that will be included in subsequent requests.