pub enum SessionSeedMode {
Fresh,
Fork,
Workspace,
}Expand description
Seed mode used when creating a peer session from an existing session.
Variants
Fresh
Create an empty session and only record lineage when provided.
Fork
Copy conversation events, workspace files, and durable session storage.
Workspace
Copy workspace files only.
Implementations