pub struct SessionParticipant {
pub id: SessionParticipantId,
pub session_id: SessionId,
pub kind: SessionParticipantKind,
pub agent_id: Option<AgentId>,
pub agent_version_id: Option<AgentVersionId>,
pub principal_id: PrincipalId,
pub role: SessionParticipantRole,
pub joined_at: DateTime<Utc>,
pub left_at: Option<DateTime<Utc>>,
}Expand description
Session participant - an agent or user that has joined a session.
Fields
id: SessionParticipantIdUnique identifier for the participant row (format: part_{32-hex}).
session_id: SessionIdSession this participant belongs to.
kind: SessionParticipantKindagent_id: Option<AgentId>Present for agent participants.
agent_version_id: Option<AgentVersionId>Immutable agent version captured for an agent participant when known.
principal_id: PrincipalIdPrincipal that joined the session.
role: SessionParticipantRolejoined_at: DateTime<Utc>left_at: Option<DateTime<Utc>>Trait Implementations
Sourceimpl Clone for SessionParticipant
impl Clone for SessionParticipant
Sourcefn clone(&self) -> SessionParticipant
fn clone(&self) -> SessionParticipant
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionParticipant
impl Debug for SessionParticipant
Sourceimpl<'de> Deserialize<'de> for SessionParticipant
impl<'de> Deserialize<'de> for SessionParticipant
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more