pub struct GrepSearchResult {
pub matches: Vec<GrepMatch>,
pub blocks: Vec<GrepContextBlock>,
pub total_matches: usize,
pub returned_matches: usize,
pub bytes_returned: usize,
pub bytes_total: usize,
pub next_offset: Option<usize>,
pub byte_truncated: bool,
}Expand description
Backend result for a bounded grep scan.
Fields
matches: Vec<GrepMatch>Flat matches are populated when both context values are zero.
blocks: Vec<GrepContextBlock>Context blocks are populated when either context value is non-zero.
total_matches: usizereturned_matches: usizebytes_returned: usizebytes_total: usizenext_offset: Option<usize>byte_truncated: boolTrait Implementations
Sourceimpl Clone for GrepSearchResult
impl Clone for GrepSearchResult
Sourcefn clone(&self) -> GrepSearchResult
fn clone(&self) -> GrepSearchResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GrepSearchResult
impl Debug for GrepSearchResult
Sourceimpl<'de> Deserialize<'de> for GrepSearchResult
impl<'de> Deserialize<'de> for GrepSearchResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more