SessionSchedule

Struct SessionSchedule 

pub struct SessionSchedule {
Show 17 fields pub id: ScheduleId, pub session_id: SessionId, pub owner_principal_id: PrincipalId, pub resolved_owner_user_id: Option<Uuid>, pub owner: Option<PrincipalSummary>, pub effective_owner: Option<PrincipalSummary>, pub description: String, pub cron_expression: Option<String>, pub scheduled_at: Option<DateTime<Utc>>, pub timezone: String, pub enabled: bool, pub schedule_type: ScheduleType, pub next_trigger_at: Option<DateTime<Utc>>, pub last_triggered_at: Option<DateTime<Utc>>, pub trigger_count: u32, pub created_at: DateTime<Utc>, pub updated_at: DateTime<Utc>,
}
A session-scoped schedule.

Fields

id: ScheduleId

Unique identifier (format: sched_{32-hex}).

session_id: SessionId

Session this schedule belongs to.

owner_principal_id: PrincipalId

Owning principal for this schedule.

resolved_owner_user_id: Option<Uuid>

Denormalized effective human owner of the owning principal lineage.

owner: Option<PrincipalSummary>

Owning principal summary.

effective_owner: Option<PrincipalSummary>

Effective human owner summary.

description: String

What the agent should do when the schedule fires.

cron_expression: Option<String>

Cron expression for recurring schedules (None for one-shot).

scheduled_at: Option<DateTime<Utc>>

One-shot trigger time (None for recurring).

timezone: String

IANA timezone for cron interpretation.

enabled: bool

Whether the schedule is active.

schedule_type: ScheduleType

Computed type based on cron_expression vs scheduled_at.

next_trigger_at: Option<DateTime<Utc>>

Next computed trigger time.

last_triggered_at: Option<DateTime<Utc>>

Last time this schedule fired.

trigger_count: u32

Total number of times this schedule has fired.

created_at: DateTime<Utc>updated_at: DateTime<Utc>

Implementations

Source

impl SessionSchedule

pub fn derive_type(cron_expression: &Option<String>) -> ScheduleType

Derive schedule type from fields.