pub struct ModelSearchMatch {
pub provider: String,
pub model_id: String,
pub display_name: Option<String>,
}Expand description
One model matched by search_provider_models, qualified by the provider
it came from.
Fields
provider: StringCaller-supplied label for the provider that offers this model.
model_id: StringExact model id, as it must be passed back to the provider.
display_name: Option<String>Human-readable name, when known.