pub struct SessionFileSystemAdapter { /* private fields */ }Expand description
Adapter that implements bashkit’s FileSystem trait by delegating to SessionFileSystem.
This provides live visibility of session files during bash execution - any files written by other tools are immediately visible, and vice versa.
Implementations
Sourceimpl SessionFileSystemAdapter
impl SessionFileSystemAdapter
pub fn new(session_id: SessionId, store: Arc<dyn SessionFileSystem>) -> Self