pub struct LlmModelWithProvider {Show 15 fields
pub id: ModelId,
pub provider_id: ProviderId,
pub model_id: String,
pub display_name: String,
pub capabilities: Vec<String>,
pub is_favorite: bool,
pub enabled: bool,
pub source: LlmModelSource,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub provider_name: String,
pub provider_type: LlmProviderType,
pub healthy: bool,
pub profile: Option<LlmModelProfile>,
pub model_vendor: Option<ModelVendor>,
}Expand description
LLM Model with provider info
Fields
id: ModelIdPrefixed public identifier. See ID Schema.
provider_id: ProviderIdOwning provider’s prefixed public identifier.
model_id: StringProvider-side model identifier as sent on the wire (e.g. gpt-4o).
display_name: StringHuman-readable display name.
capabilities: Vec<String>Capability tags supported by this model.
is_favorite: boolWhether this model is starred in the UI for quick access.
enabled: boolWhether this model is selectable. Controls UI visibility AND server-side resolution: LlmResolverService requires enabled = true, and org default-model validation rejects disabled models.
source: LlmModelSourceHow this model entry was added (manually, discovered, or seeded as predefined).
created_at: DateTime<Utc>Timestamp when this model was created (RFC 3339).
updated_at: DateTime<Utc>Timestamp when this model was last updated (RFC 3339).
provider_name: StringJoined provider display name.
provider_type: LlmProviderTypeJoined provider implementation type.
healthy: boolDerived: model is configured and ready for use. Currently means the joined provider is active and has an API key set; over time this may also incorporate live reachability checks. Not persisted.
profile: Option<LlmModelProfile>Readonly profile with model capabilities (limits, pricing, modalities). Not persisted.
model_vendor: Option<ModelVendor>Vendor/brand of the model, derived from the model registry. Drives UI
branding (icons). None when the model id is not in the registry. Not persisted.