Structs
- Annotation
Source - The source a
TextAnnotationpoints to. - Controls
- Runtime controls for message processing
- External
Actor - External actor identity for messages originating from external channels (Slack, Discord, Teams, etc.).
- Image
Content Part - Image content part (base64 or URL)
- Image
File Content Part - Image file content part (reference to uploaded image)
- Message
- A message in the conversation
- Reasoning
Config - Reasoning configuration for the model
- Text
Annotation - A claim-level citation attached to a span of generated text.
- Text
Content Part - Text content part
- Tool
Call Content Part - Tool call content part (assistant requesting tool execution)
- Tool
Result Content Part - Tool result content part (result of tool execution)
- Verification
Verdict - Outcome of citation verification (see the
citation_verificationcapability).
Enums
- Content
Part - A part of message content - can be text, image, image_file, tool_call, or tool_result
- Content
Type - Content type discriminator
- Execution
Phase - Execution phase for assistant messages in multi-step tool-calling flows.
- Input
Content Part - Input content part - text, image, and image_file (for user input)
- Message
Role - Message role in the conversation
- Verification
Status - Whether a cited source entails the claim it is attached to.
Functions
- patch_
dangling_ tool_ calls - Patch dangling tool calls by adding synthetic “cancelled” results.