pub struct SessionSchedule {Show 17 fields
pub id: ScheduleId,
pub session_id: SessionId,
pub owner_principal_id: PrincipalId,
pub resolved_owner_user_id: Option<Uuid>,
pub owner: Option<PrincipalSummary>,
pub effective_owner: Option<PrincipalSummary>,
pub description: String,
pub cron_expression: Option<String>,
pub scheduled_at: Option<DateTime<Utc>>,
pub timezone: String,
pub enabled: bool,
pub schedule_type: ScheduleType,
pub next_trigger_at: Option<DateTime<Utc>>,
pub last_triggered_at: Option<DateTime<Utc>>,
pub trigger_count: u32,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Expand description
A session-scoped schedule.
Fields
id: ScheduleIdUnique identifier (format: sched_{32-hex}).
session_id: SessionIdSession this schedule belongs to.
owner_principal_id: PrincipalIdOwning principal for this schedule.
resolved_owner_user_id: Option<Uuid>Denormalized effective human owner of the owning principal lineage.
owner: Option<PrincipalSummary>Owning principal summary.
effective_owner: Option<PrincipalSummary>Effective human owner summary.
description: StringWhat the agent should do when the schedule fires.
cron_expression: Option<String>Cron expression for recurring schedules (None for one-shot).
scheduled_at: Option<DateTime<Utc>>One-shot trigger time (None for recurring).
timezone: StringIANA timezone for cron interpretation.
enabled: boolWhether the schedule is active.
schedule_type: ScheduleTypeComputed type based on cron_expression vs scheduled_at.
next_trigger_at: Option<DateTime<Utc>>Next computed trigger time.
last_triggered_at: Option<DateTime<Utc>>Last time this schedule fired.
trigger_count: u32Total number of times this schedule has fired.
created_at: DateTime<Utc>updated_at: DateTime<Utc>Implementations
Sourceimpl SessionSchedule
impl SessionSchedule
Sourcepub fn derive_type(cron_expression: &Option<String>) -> ScheduleType
pub fn derive_type(cron_expression: &Option<String>) -> ScheduleType
Derive schedule type from fields.